@@ -12,10 +12,17 @@ from typing import Any, cast
 
 import vapoursynth as vs
 import vsutil
-from vsexprtools.util import to_arr
+from vsexprtools import to_arr
 from vskernels import Bicubic
 
-from .utils import checkValue
+__all__ = [
+    'SetsuCubic',
+    'source', 'src',
+    'set_output', 'output',
+    'x8_SHADERS', 'x16_SHADERS', 'x56_SHADERS',
+    'SSIM_DOWNSCALER_SHADERS', 'SSIM_SUPERSAMPLER_SHADERS'
+
+]
 
 core = vs.core
 
@@ -32,11 +39,16 @@ class SetsuCubic(Bicubic):
         super().__init__(b=-0.26470935063297507, c=0.7358829780174403, **kwargs)
 
 
+def checkValue(condition: bool, error_message: str) -> None:
+    if condition:
+        raise ValueError(error_message)
+
+
 def set_output(clip: vs.VideoNode, text: bool | int | str | tuple[int, int] | tuple[int, int, str] = True) -> None:
     index = len(vs.get_outputs())
 
     ref_id = str(id(clip))
-    arr = to_arr(text)  # type: ignore
+    arr = to_arr(text)
 
     if any([isinstance(x, str) for x in arr]):
         ref_name = arr[-1]
