@@ -7,7 +7,7 @@ from math import ceil
 from typing import NamedTuple, cast
 
 import vapoursynth as vs
-from vsexprtools.util import clamp
+from vsexprtools import clamp
 from vskernels import Catrom, Kernel
 from vsutil import disallow_variable_format, insert_clip
 
@@ -15,6 +15,14 @@ from .easing import F_Easing, Linear, OnAxis
 from .types import Range
 from .utils import change_fps
 
+__all__ = [
+    'fade', 'fade_freeze', 'fade_in', 'fade_out',
+    'fade_in_freeze', 'fade_out_freeze',
+    'crossfade', 'fade_ranges',
+    'PanDirection', 'PanFunction', 'PanFunctions',
+    'panner'
+]
+
 core = vs.core
 
 
